@@ -56,7 +56,7 @@ from kitchen.text.converters import to_bytes
 import urllib3
 
 from fedora import __version__
-from fedora.client import AuthError, ServerError, LoginRequiredError, FedoraServiceError
+from fedora.client import AuthError, ServerError, FedoraServiceError
 
 log = logging.getLogger(__name__)
 log.addHandler(NullHandler())
